@@ -40,5 +40,10 @@ class Settings:
         """
         return {k: getattr(self, k) for k in dir(self) if k.upper() == k}
 
+    @property
+    def DISPLAY_DROP_DOWN_MENU_CONDITION_FUNCTION(self):
+        return getattr(django_settings, "ADMIN_INDEX_DISPLAY_DROP_DOWN_MENU_CONDITION_FUNCTION",
+                       "django_admin_index.utils.should_display_dropdown_menu")
+
 
 settings = Settings()
